@@ -1,7 +1,7 @@
 import sys
 sys.path.append('../MachineLearningPackage/')
 
-from pylearn.treat_data.load_data import LoadData
+from pyLearnAlgorithms.load_data import LoadData
 
 json_file = LoadData('tests/datasets', 'JSONfile.json')
 
