@@ -1,8 +1,8 @@
 import sys
 sys.path.append('../MachineLearningPackage/')
 
-from pylearn.treat_data.load_data import LoadData
-from pylearn.treat_data.split_data import SplitData
+from pyLearnAlgorithms.load_data import LoadData
+from pyLearnAlgorithms.split_data import SplitData
 
 json_file = LoadData('tests/datasets', 'JSONfile.json')
 
